# grub2systemd

Convert Grub2 grub.cfg menuentries to systemd-boot EFI loader entries

Requires `blkid` to be installed.

## Installation
`pip3 install g2sd`

## Usage
`g2sd /boot/grub/grub.cfg /boot`

## License
See `LICENSE`. Message me if you'd like to use this project with a different license.
